import{d as t,o as a,Y as o,b as s,u as c,by as r,a0 as _}from"./index.ea15e788.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f5c736e8-8ad8-4c02-ad94-457d5d3418c2",e._sentryDebugIdIdentifier="sentry-dbid-f5c736e8-8ad8-4c02-ad94-457d5d3418c2")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,d)=>(a(),o("div",i,[s(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.6dd9b38a.js.map
