import{b as o,ee as c,ei as u}from"./index.ea15e788.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="18d6e9ed-cdee-456c-9584-d01592d1ed2e",e._sentryDebugIdIdentifier="sentry-dbid-18d6e9ed-cdee-456c-9584-d01592d1ed2e")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(d){return Object.getOwnPropertyDescriptor(r,d).enumerable}))),n.forEach(function(d){a(e,d,r[d])})}return e}function a(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=l({},t,r.attrs);return o(c,l({},n,{icon:u}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;const f=i;export{f as C};
//# sourceMappingURL=CloseCircleOutlined.411285dd.js.map
