import{O as r}from"./workspaceStore.bdb77ad7.js";import{d as c,X as l,o as i,Y as u,b as a,w as o,u as n,aG as d,dd as f,dc as b}from"./index.ea15e788.js";import"./url.d05e65d7.js";import"./colorHelpers.d0003e86.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4fbb7c89-d9cc-47d8-9f72-e2c8906b7f4a",e._sentryDebugIdIdentifier="sentry-dbid-4fbb7c89-d9cc-47d8-9f72-e2c8906b7f4a")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.585b9b96.js.map
