import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.2501f0d1.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.ea15e788.js";import"./gateway.5334dd49.js";import"./popupNotifcation.b87da6c9.js";import"./fetch.3a83f9f2.js";import"./record.907dac13.js";import"./SaveButton.00be2f9f.js";import"./UnsavedChangesHandler.328c6c59.js";import"./ExclamationCircleOutlined.5d3118bd.js";import"./CrudView.68caab1a.js";import"./router.c735a703.js";import"./Badge.06a33f73.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.622d1777.js";import"./BookOutlined.63fa8786.js";import"./url.d05e65d7.js";import"./PhDotsThreeVertical.vue.9be47507.js";import"./index.fd4ec281.js";import"./index.ee7a7065.js";import"./asyncComputed.d5cfb74d.js";import"./polling.01693b7a.js";import"./PhPencil.vue.2fbe6402.js";import"./index.85e2ba9b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="37d76e22-64fe-44a3-8387-a4aa6d619e64",o._sentryDebugIdIdentifier="sentry-dbid-37d76e22-64fe-44a3-8387-a4aa6d619e64")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.bd15692e.js.map
