import{k as a,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.ea15e788.js";import{s as y,c as l,a as i}from"./workspaceStore.bdb77ad7.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.0f48e8c8.js";import"./url.d05e65d7.js";import"./colorHelpers.d0003e86.js";import"./PlayerConfigProvider.16cb12f9.js";import"./index.1ed51f05.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7889f7a7-a72d-47f5-996b-c94ee52d3f17",t._sentryDebugIdIdentifier="sentry-dbid-7889f7a7-a72d-47f5-996b-c94ee52d3f17")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=a({render:()=>f(b)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.06d3d766.js.map
