import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.9d8200b8.js";import{R as f}from"./tasksController.124792c6.js";import{d as _,ea as b,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.ea15e788.js";import"./gateway.5334dd49.js";import{a as j,B as x}from"./build.a5b8faaa.js";import{a as C}from"./project.3e59bdc6.js";import"./tables.c4a68924.js";import{a as D}from"./asyncComputed.d5cfb74d.js";import"./metadata.292188c0.js";import"./PhWebhooksLogo.vue.b0209693.js";import"./ant-design.bd02d7e1.js";import"./string.f9be58bd.js";import"./dayjs.4a2eb153.js";import"./index.fd4ec281.js";import"./scripts.3569640e.js";import"./record.907dac13.js";import"./linters.c0ab638e.js";import"./polling.01693b7a.js";import"./popupNotifcation.b87da6c9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ae4ec38e-c353-4909-94f5-e617aebe4946",e._sentryDebugIdIdentifier="sentry-dbid-ae4ec38e-c353-4909-94f5-e617aebe4946")}catch{}})();const Q=_({__name:"Tasks",setup(e){const a=b().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:c}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.2ee90f70.js.map
