import"./App.vue_vue_type_style_index_0_lang.0f48e8c8.js";import{_ as u}from"./App.vue_vue_type_style_index_0_lang.0f48e8c8.js";import"./workspaceStore.bdb77ad7.js";import"./index.ea15e788.js";import"./url.d05e65d7.js";import"./colorHelpers.d0003e86.js";import"./PlayerConfigProvider.16cb12f9.js";import"./index.1ed51f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="98f05ff9-b441-407f-a060-7465e6f62a6d",e._sentryDebugIdIdentifier="sentry-dbid-98f05ff9-b441-407f-a060-7465e6f62a6d")}catch{}})();export{u as default};
//# sourceMappingURL=App.96419b19.js.map
