import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.9d8200b8.js";import{L as i}from"./tasksController.124792c6.js";import{d as c,o as p,c as d,w as o,b as s,aG as _,u as a,dd as f,a0 as m}from"./index.ea15e788.js";import{C as l}from"./ContentLayout.9effa68b.js";import"./metadata.292188c0.js";import"./PhWebhooksLogo.vue.b0209693.js";import"./ant-design.bd02d7e1.js";import"./string.f9be58bd.js";import"./dayjs.4a2eb153.js";import"./index.fd4ec281.js";import"./gateway.5334dd49.js";import"./popupNotifcation.b87da6c9.js";import"./scripts.3569640e.js";import"./record.907dac13.js";import"./linters.c0ab638e.js";import"./asyncComputed.d5cfb74d.js";import"./polling.01693b7a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d2bfce61-34ce-4502-9f27-ec5311ebbc17",e._sentryDebugIdIdentifier="sentry-dbid-d2bfce61-34ce-4502-9f27-ec5311ebbc17")}catch{}})();const u=c({__name:"Tasks",setup(e){const t=new i;return(r,b)=>(p(),d(l,null,{default:o(()=>[s(a(f),null,{default:o(()=>[_("Tasks")]),_:1}),s(n,{class:"tasks",api:a(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.b508da0b.js.map
