import{d as i,o as p,c as n,w as m,b as s,u as r}from"./index.ea15e788.js";import"./linters.c0ab638e.js";import{W as a}from"./workspaces.3eb1c958.js";import{C as d}from"./ContentLayout.9effa68b.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.2501f0d1.js";import"./asyncComputed.d5cfb74d.js";import"./workspaceStore.bdb77ad7.js";import"./url.d05e65d7.js";import"./colorHelpers.d0003e86.js";import"./record.907dac13.js";import"./gateway.5334dd49.js";import"./popupNotifcation.b87da6c9.js";import"./fetch.3a83f9f2.js";import"./SaveButton.00be2f9f.js";import"./UnsavedChangesHandler.328c6c59.js";import"./ExclamationCircleOutlined.5d3118bd.js";import"./CrudView.68caab1a.js";import"./router.c735a703.js";import"./Badge.06a33f73.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.622d1777.js";import"./BookOutlined.63fa8786.js";import"./PhDotsThreeVertical.vue.9be47507.js";import"./index.fd4ec281.js";import"./index.ee7a7065.js";import"./polling.01693b7a.js";import"./PhPencil.vue.2fbe6402.js";import"./index.85e2ba9b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="d669984e-60ae-40eb-831f-3c1c9beb2ef0",o._sentryDebugIdIdentifier="sentry-dbid-d669984e-60ae-40eb-831f-3c1c9beb2ef0")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const e=new c;return(t,u)=>(p(),n(d,null,{default:m(()=>[s(f,{"env-var-repository":r(e),mode:"editor","file-opener":r(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.a3ce132c.js.map
