import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.14373e10.js";import{d as f,eo as m,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.ea15e788.js";import{u as h}from"./workspaceStore.bdb77ad7.js";import"./Logo.57ffcb9b.js";import"./string.f9be58bd.js";import"./CircularLoading.057be8a6.js";import"./index.1ed51f05.js";import"./index.85e2ba9b.js";import"./url.d05e65d7.js";import"./colorHelpers.d0003e86.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b6271fbc-0b6d-4080-9125-c6f6c3381356",e._sentryDebugIdIdentifier="sentry-dbid-b6271fbc-0b6d-4080-9125-c6f6c3381356")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var c,d,p,u,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.bdc4c3de.js.map
